@@ -1,13 +1,13 @@
-join <- function(J, D, var, cond, G.Adj) {
+join <- function(J, D, vari, cond, G.Adj) {
   J.new <- character()
   D.new <- character()
   if (length(J) == 0) {
-    J.new <- var
+    J.new <- vari
     D.new <- cond
     return(list(J.new, D.new))
   }
 
-  if (length(intersect(J, cond)) > 0 && var %in% D) {
+  if (length(intersect(J, cond)) > 0 && vari %in% D) {
     return(list(J, D))
   }
 
@@ -17,17 +17,17 @@ join <- function(J, D, var, cond, G.Adj) {
     ds <- powerset(cond.uni, nonempty = FALSE)
     n <- length(ds)
     for (i in 1:n) {
-      a.set <- union(setdiff(ds[[i]], setdiff(D, var)), setdiff(setdiff(D, var), ds[[i]]))
+      a.set <- union(setdiff(ds[[i]], setdiff(D, vari)), setdiff(setdiff(D, vari), ds[[i]]))
       b.set <- union(setdiff(ds[[i]], setdiff(cond, J)), setdiff(setdiff(cond, J), ds[[i]]))
       if (wrap.dSep(G.Adj, J, a.set, setdiff(D, a.set)) && 
-          wrap.dSep(G.Adj, var, b.set, setdiff(cond, b.set))) {
-        J.new <- union(J, var)
+          wrap.dSep(G.Adj, vari, b.set, setdiff(cond, b.set))) {
+        J.new <- union(J, vari)
         D.new <- ds[[i]]
         return(list(J.new, D.new))
       }
     } 
   } else {
-    J.new <- union(J, var)
+    J.new <- union(J, vari)
     D.new <- cond
     return(list(J.new, D.new))
   }
