@@ -12,8 +12,10 @@ function(file, nodes, use.names) {
     for (i in 1:length(node.data)) nodes[i] <- xmlValue(node.data[[i]]["NodeLabel"]$NodeLabel[1]$text)
   }
   all <- getNodeSet(doc, "//*[position() > 1]", ns)
-  keep <- getNodeSet(doc, "//ns:edge | //ns:node | //ns:graph | //ns:key[@attr.name] | //ns:data[contains(@key,'d9')]", ns)
-  removeNodes(setdiff(all, keep))
+  keep <- getNodeSet(doc, "//ns:edge | //ns:node | //ns:graph | //ns:key[@attr.name = 'description'] | //ns:data[contains(@key,'d9')]", ns)
+  remove <- getNodeSet(doc, "//ns:key[@for='port'] | //ns:key[@for='graphml'] | //ns:data[@key='d4'] | //ns:data[@key='d6'] 
+ | //ns:data[@key='d7'] | //ns:data[@key='d8'] | //ns:data[@key='d10']" , ns)
+  removeNodes(union(setdiff(all, keep), remove))
   temp <- tempfile(fileext = ".graphml")
   temp.xml <- saveXML(doc, file = temp)
   free(doc)
